@@ -1,6 +1,7 @@
 
 from argparse import ArgumentParser, Namespace
 import logging
+import os
 from typing import Dict
 from shutil import copyfile
 from distutils.dir_util import copy_tree
@@ -8,9 +9,10 @@ from distutils.dir_util import copy_tree
 from rich.progress import track
 
 from dotfiles.core.dry import call
-from dotfiles.core.matcher import match, ConfigurationFileType
+from dotfiles.core.matcher import ConfigurationMatchStatus, match, ConfigurationFileType
 
 COMMAND = "sync"
+ALLOWED_MATCH_STATUSES = [ConfigurationMatchStatus.SYNCHRONIZABLE]
 
 logger = logging.getLogger(__name__)
 
@@ -27,8 +29,14 @@ def run(config: Dict, args: Namespace):
 
     for config in track(matches, description='Syncing Configuration...', disable=hide_progress):
 
+        if config.status not in ALLOWED_MATCH_STATUSES:
+            logger.warning('%s had status %s. Skipping.', config.key, config.status)
+            continue
+
         if config.source_type == ConfigurationFileType.FILE:
             logger.info('Copying File %s => %s', config.source, config.target)
+            directory = os.path.dirname(config.target)
+            call(os.makedirs, args.dry, args.interactive, directory, exist_ok=True)
             call(copyfile, args.dry, args.interactive, config.source, config.target)
 
         elif config.source_type == ConfigurationFileType.DIRECTORY:
