@@ -9,9 +9,10 @@ from distutils.dir_util import copy_tree
 from rich.progress import track
 
 from dotfiles.core.dry import call
-from dotfiles.core.matcher import match, ConfigurationFileType
+from dotfiles.core.matcher import ConfigurationMatchStatus, match, ConfigurationFileType
 
 COMMAND = "update"
+ALLOWED_MATCH_STATUSES = [ConfigurationMatchStatus.SYNCHRONIZABLE, ConfigurationMatchStatus.MISSING_SOURCE_FILE]
 
 logger = logging.getLogger(__name__)
 
@@ -28,6 +29,10 @@ def run(config: Dict, args: Namespace):
 
     for config in track(matches, description=f'Updating Configuration Directory: {config_dir}', disable=hide_progress):
 
+        if config.status not in ALLOWED_MATCH_STATUSES:
+            logger.warning('%s had status %s. Skipping.', config.key, config.status)
+            continue
+
         if config.source_type == ConfigurationFileType.FILE:
             logger.info('Copying File %s => %s', config.target, config.source)
 
